aboutsummaryrefslogtreecommitdiffstats
path: root/perllib/Open311/PopulateServiceList.pm
diff options
context:
space:
mode:
Diffstat (limited to 'perllib/Open311/PopulateServiceList.pm')
-rw-r--r--perllib/Open311/PopulateServiceList.pm7
1 files changed, 4 insertions, 3 deletions
diff --git a/perllib/Open311/PopulateServiceList.pm b/perllib/Open311/PopulateServiceList.pm
index b0ffe3806..949e2baa9 100644
--- a/perllib/Open311/PopulateServiceList.pm
+++ b/perllib/Open311/PopulateServiceList.pm
@@ -286,9 +286,10 @@ sub _delete_contacts_not_in_service_list {
}
);
- # for Warwickshire, which is mixed Open311 and email, don't delete the email
- # addresses
- if ($self->_current_body->name eq 'Warwickshire County Council') {
+ # for Warwickshire/Bristol, which are mixed Open311 and email, don't delete
+ # the email addresses
+ if ($self->_current_body->name eq 'Warwickshire County Council' ||
+ $self->_current_body->name eq 'Bristol City Council') {
$found_contacts = $found_contacts->search(
{
email => { -not_like => '%@%' }